@@ -2,8 +2,7 @@
 
 Simply invokes :func:`gptsum.cli.main`.
 """
-
 import gptsum.cli
 
 if __name__ == "__main__":
-    gptsum.cli.main()  # pragma: no cover
+    gptsum.cli.main()
